/* sequence.h */

/*****************************************************************
        Copyright by Rockefeller University,
can not be reproduced or distributed without written permission of
the copyright holder.  Version 1.1 of April 2006.

Written by Alexandre Morozov (contact person: morozov@edsb.rockefeller.edu),
and Eric Siggia.

The program DYNAPRO implements a dynamic programming algorithm for predicting
DNA occupancies by arbitrary objects whose interaction energies with DNA are
known for each possible binding position.

The DYNAPRO method and its applications are described in the following
paper:

******************************************************************/

#ifndef _sequence_h_
#define _sequence_h_

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <assert.h>
#include <vector>

#define MAX_ALIGNED_SEQUENCES 2

extern int  numsequencesread;
//class Alignment;

class Sequence {
  char  *_seq;
  char  *_indexseq;        
  int   _length;
  char  _name[1024];

  int   _id;
  void  *_udata;

  char   *ReadFasta(FILE *fp);
public:
  static const int MAX_LINE_LENGTH = 1024;
  static const int MAX_SEQ_LENGTH = 40000000;

  Sequence(char *flname);
  Sequence(char *seq, int length, char *name);
  Sequence(Sequence &src);
  ~Sequence();

  int   Length();
  char  CharAt(int index);
  void  Mask(int pos);
  char  IndexOfCharAt(int index);
  char *SeqIndices(void);
  char *SeqString(void);
  bool  AmbiguousCharAt(int index);
  void  Print(int start, int stop);
  void  Name(char *name);

  void  SetSpeciesIndex(int i);    
  int   GetSpeciesIndex();

  void  SetUserData(void *udata);
  void  *GetUserData();
  
  void  Mutate(int index, char nt_type);
};

#endif

