/* options.c */

/*****************************************************************
        Copyright by Rockefeller University,
can not be reproduced or distributed without written permission of
the copyright holder.  Version 1.1 of April 2006.

Written by Alexandre Morozov (contact person: morozov@edsb.rockefeller.edu),
and Eric Siggia.

The program DYNAPRO implements a dynamic programming algorithm for predicting
DNA occupancies by arbitrary objects whose interaction energies with DNA are
known for each possible binding position.

The DYNAPRO method and its applications are described in the following
paper:

******************************************************************/

#include "options.h"

/////////////////////////////////////////////////////////////////////
///// SYNOPSIS //////////////////////////////////////////////////////
///// Command-line arguments are read here //////////////////////////
/////////////////////////////////////////////////////////////////////

struct Options *ReadArguments(int &argbase, int argc, char **argv)
{
  struct Options *opt = new struct Options;
  while (argbase < argc && argv[argbase][0]=='-') {
    if (strstr(argv[argbase],"-fasta")) {
      argbase++;
      if (argbase >= argc) { // input FASTA file
	printf("Error: -fasta must be followed by a FASTA file!\n");
	exit(1);
      }
      opt->fasta = argv[argbase];
      argbase++;
      continue;
    }
    if (strstr(argv[argbase],"-et")) { // input file with energy landscape filenames and Lembed values
      argbase++;
      if (argbase >= argc) {
	printf("Error: -et must be followed by a file with energy landscapes and Lembed values!\n");
	exit(1);
      }
      opt->et = argv[argbase];
      argbase++;
      continue;
    }
    if (strstr(argv[argbase],"-out")) { // output filename [optional]
      argbase++;
      if (argbase >= argc) {
	printf("Error: -out must be followed by an output filename!\n");
	exit(1);
      }
      opt->out = argv[argbase];
      argbase++;
      continue;
    }
    if (strstr(argv[argbase],"-bw")) { // strand bias [optional]
      opt->bw = atof(argv[++argbase]);
      argbase++;
      continue;
    }
    if (strstr(argv[argbase],"-bkgr")) { // choice of bkrg seq model [optional]
      argbase++;
      if (argbase >= argc) {
	printf("Error: -bkgr must be followed by a name specifying choice of bkgr!\n");
	exit(1);
      }
      opt->bkgr = argv[argbase];
      argbase++;
      continue;
    }
    if (strstr(argv[argbase],"-enforceP")) { // choice of minimal starting probability for all objects [optinal]
      argbase++;
      if (argbase >= argc) {
	printf("Error: -enforceP must be followed by a file with Pmin values!\n");
	exit(1);
      }
      opt->enforceP = argv[argbase];
      argbase++;
      continue;
    }
    printf("Error: option %s not recognized\n",argv[argbase]);
    exit(1);
  }
  
  return opt;
}

