/* stats.c */

/*****************************************************************
        Copyright by Rockefeller University,
can not be reproduced or distributed without written permission of
the copyright holder.  Version 1.1 of April 2006.

Written by Alexandre Morozov (contact person: morozov@edsb.rockefeller.edu),
and Eric Siggia.

The program DYNAPRO implements a dynamic programming algorithm for predicting
DNA occupancies by arbitrary objects whose interaction energies with DNA are
known for each possible binding position.

The DYNAPRO method and its applications are described in the following
paper:

******************************************************************/

#include "stats.h"

double ave(std::vector<double> &c) {
  double ave = 0.0;
  unsigned int csize = c.size();
  if (csize > 0) {
    for (unsigned int j=0; j<csize; ++j) {
      ave += c[j];
    }
    ave /= csize;
  }
  return ave;
}

double covar(std::vector<double> &c1, std::vector<double> &c2) {
  if (c1.size() != c2.size() ) {
    std::cerr << "Arrays of unequal length!\n";
    exit(EXIT_FAILURE);
  }
  double covar = 0.0;
  for (unsigned int i=0; i<c1.size(); ++i) {
    covar += (c1[i] * c2[i]);
  }
  if (c1.size() > 0) {
    covar /= c1.size();
  }
  double m1 = ave(c1);
  double m2 = ave(c2);
  
  return (covar - m1*m2);
}

double var(std::vector<double> &c) {
  double var = covar(c,c);
  
  return var;
}

